@@ -22,7 +22,7 @@ class AccountBalance(QuickRestoObject):
                  **kwargs):
         class_name = 'ru.edgex .quickresto.modules.crm.accounting.account.balance.AccountBalance'
 
-        super().__init__(id=0, class_name=class_name, **kwargs)
+        super().__init__(class_name=class_name, **kwargs)
         self._available: float = available
         self._credit_hold: float = creditHold
         self._debit_hold: float = debitHold
