@@ -26,7 +26,7 @@ class AccountType(QuickRestoObject):
                  resetPeriod: float = None, **kwargs):
         class_name = "ru.edgex.quickresto.modules.crm.accounting.account.account_balance.AccountType"
 
-        super().__init__(id=0, class_name=class_name, **kwargs)
+        super().__init__(class_name=class_name, **kwargs)
         self._name: str = name
         self._account_guid: str = accountGuid
         self._deleted: bool = deleted
