@@ -34,6 +34,6 @@ class ContactMethod(QuickRestoObject):
     def __init__(self, type: str = None, value: str = None, **kwargs):
         class_name: str = 'modules.crm.accounting.account.contact_method'
 
-        super().__init__(id=0, class_name=class_name, **kwargs)
+        super().__init__(class_name=class_name, **kwargs)
         self._value: str = value
         self._contact_type: ContactMethodType = convert_str_to_contact_method_type(type)
