@@ -9,7 +9,7 @@ class CustomerAccount(QuickRestoObject):
                  hidden: bool = None, **kwargs):
         class_name = 'ru.edgex.quickresto.modules.crm.accounting.account.CustomerAccount'
 
-        super().__init__(id=0, class_name=class_name, **kwargs)
+        super().__init__(class_name=class_name, **kwargs)
 
         if accountBalance is not None: 
             self._accounts = AccountBalance(**accountBalance)
