@@ -1,4 +1,5 @@
 from quick_resto_API.quick_resto_objects.modules.core.payment import Payment
+from quick_resto_API.quick_resto_objects.modules.crm.customer import CrmCustomer
 from quick_resto_API.quick_resto_objects.modules.front.order_item import OrderItem
 from quick_resto_API.quick_resto_objects.modules.front.table_scheme import TableScheme
 from quick_resto_API.quick_resto_objects.modules.front.terminal import Terminal
@@ -6,6 +7,7 @@ from quick_resto_API.quick_resto_objects.modules.front.shift import Shift
 from quick_resto_API.quick_resto_objects.modules.personnel.employee import Employee
 from quick_resto_API.quick_resto_objects.quick_resto_object import QuickRestoObject
 from quick_resto_API.quick_resto_objects.modules.warehouse.sale_place import SalePlace
+from quick_resto_API.quick_resto_objects.modules.front.table import Table
 
 
 class OrderInfo(QuickRestoObject):
@@ -17,6 +19,10 @@ class OrderInfo(QuickRestoObject):
     def create_date(self) -> str:
         return self._create_date
 
+    @property
+    def table_order_create_time(self) -> str:
+        return self._table_order_create_time
+
     @property
     def document_number(self) -> int:
         return self._document_number
@@ -129,6 +135,14 @@ class OrderInfo(QuickRestoObject):
     def order_item_list(self) -> list:
         return self._order_item_list
 
+    @property
+    def payer(self) -> CrmCustomer:
+        return self._payer
+
+    @property
+    def table(self) -> Table:
+        return self._table
+
     def __init__(self, comment: str = None, createDate: str = None, documentNumber: int = None,
                  discountPercent: float = None, cashier: dict = None, extId: str = None,
                  front: dict = None, frontSum: float = None, frontTotalAbsoluteCharge: float = None,
@@ -136,16 +150,17 @@ class OrderInfo(QuickRestoObject):
                  frontTotalCard: float = None, frontTotalCashMinusDiscount: float = None, frontTotalDiscount: float = None,
                  frontTotalPrice: float = None, createTerminalSalePlace:dict = None,
                  kkmTerminalName: str = None, originalOrderDocId: str = None, precheckDocId: str = None,
-                 reopenedOrderDocId: str = None, returned: bool = None,
+                 reopenedOrderDocId: str = None, returned: bool = None, tableOrderCreateTime: str = None,
                  returnOrderDocId: str = None, shift: dict = None, shiftId: str = None, tableScheme: dict = None,
                  tableOrderDocId: str = None, totalSum: float = None, orderItemList:list = None,
-                 waiter: dict = None,payments:list = None, **kwargs):
+                 waiter: dict = None,payments:list = None, payer: dict = None, table:dict = None, **kwargs):
         class_name = "ru.edgex.quickresto.modules.front.orders.OrderInfo"
 
         super().__init__(class_name=class_name, **kwargs)
 
         self._comment: str = comment
         self._create_date: str = createDate
+        self._table_order_create_time:str = tableOrderCreateTime
         self._document_number: int = documentNumber
         self._discount_percent: float = discountPercent
         
@@ -210,3 +225,13 @@ class OrderInfo(QuickRestoObject):
             self._order_item_list = [OrderItem(**item) for item in orderItemList]
         else:
             self._order_item_list = None
+
+        if payer is not None:
+            self._payer = CrmCustomer(**payer)
+        else:
+            self._payer = None
+
+        if table is not None:
+            self._table = Table(**table)
+        else:
+            self._table = None
