@@ -75,6 +75,6 @@ class IncomingInvoice(QuickRestoObject):
             elif provider is ProviderGroup:
                 self._provider = ProviderGroup(**provider)
             else:
-                provider = None
+                self._provider = None
         else:
-                provider = None
+                self._provider = None
